import os
import subprocess

from charmhelpers.core.host import service_restart

import charms.apt

from charms.reactive import (
    when, when_not,
)

from charmhelpers.core.hookenv import (
    status_set,
    config, log,
    open_port,
)

from yaml import dump

try:
        from yaml import CDumper as Dumper
except ImportError:
        from yaml import Dumper

config_file = '/etc/default/ceph_dash.yaml'


@when_not('config.set.repository')
def set_blocked():
    status_set('blocked', 'You must set repository to the format '
               '`deb https://username:password@path trusty main`')


@when('config.set.repository', 'config.set.apt_key')
@when_not('apt.installed.ceph-dash')
def setup_apt():
    charms.apt.add_source(config('repository'), key=config('apt_key'))
    charms.apt.queue_install(['ceph-dash'])


@when('apt.installed.ceph-dash')
def setup_nginx():
    if os.path.isfile('/etc/nginx/sites-enabled/default'):
        os.remove('/etc/nginx/sites-enabled/default')
        service_restart('nginx')


@when('apt.installed.ceph-dash')
@when_not('influx.available')
def waiting_on_influx():
    status_set('blocked', 'Please add a relation to InfluxDB')


def restart():
    try:
        service_restart('nginx')
        service_restart('ceph-dash')
    except subprocess.CalledProcessError as err:
        log('Service restart failed with err: ' + err.message)


@when('influx.available', 'apt.installed.ceph-dash')
def setup_influx(influx):
    influx_config = {
        'host': influx.hostname(),
        'port': influx.port(),
        'user': influx.user(),
        'password': influx.password(),
    }
    service_dict = {'influx': influx_config}
    update_service_config(service_dict=service_dict)
    restart()
    open_port(80)
    status_set('active', '')


def update_service_config(service_dict):
    '''Expects a dict of params for influx:
    {'influx': { 'host': '127.0.0.1'} }'''
    # assert isinstance(option_list, list)
    assert isinstance(service_dict, dict)

    log('creating new service config file: ' + str(service_dict))
    write_config(service_dict)


def write_config(service_dict):
    try:
        with open(config_file, 'w+') as config:
            config.write(
                dump(data=service_dict, Dumper=Dumper))
    except IOError as err:
        log("IOError with {}:{}".format(config_file, err.message))
